Documentation
¶
Overview ¶
Package stacks provides various implementations of a stack data structure, each ideal for a certain set of use cases and conditions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Stack ¶
A Stack implements the basic stack data structure operations, including Push, Pop, Peek, Empty, and Size.
func Linked ¶
Linked creates an implementation of Stack backed by a linked-list. This is a good choice for use cases where the size of the stack changes dramatically and often. Unlike a slice, the backing data structure will not need to be copied as the size of the stack changes, as each element is allocated individually in the linked list.
Click to show internal directories.
Click to hide internal directories.